#
# spec file for package aspell-en
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define aspell_dict_dir %(aspell dump config dict-dir)
%define aspell_data_dir %(aspell dump config data-dir)

Name:           aspell-en
Version:        2020.12.07
Release:        2.3
Summary:        English Dictionaries for ASpell
License:        MIT AND BSD-3-Clause
Group:          Productivity/Text/Spell

URL:            http://wordlist.aspell.net/
Source0:        https://ftp.gnu.org/gnu/aspell/dict/en/aspell6-en-%{version}-0.tar.bz2
Source1:        https://ftp.gnu.org/gnu/aspell/dict/en/aspell6-en-%{version}-0.tar.bz2.sig
# keyring from ftp://ftp.gnu.org/gnu/aspell/dict/0index.html
#   http://aspell.net/dict-upload-key.txt + http://kevin.atkinson.dhs.org/public-key.txt
Source2:        aspell-en.keyring

BuildRequires:  aspell >= 0.60
BuildRequires:  fdupes
Provides:       locale(aspell:en)

%description
An English, Canadian English and British English dictionary for the ASpell
spell checker.

%prep
%setup -q -n aspell6-en-%{version}-0

%build
#not autoconf
./configure
make %{?_smp_mflags}

%install
%makeinstall
fdupes %{buildroot}%{aspell_dict_dir}

%files
%license Copyright
%doc README doc/ChangeLog doc/SCOWL-README doc/extra.txt
%{aspell_dict_dir}/*.rws
%{aspell_dict_dir}/*.multi
%{aspell_dict_dir}/*.alias
%{aspell_data_dir}/*.dat

%changelog
* Thu Jul  7 2022 Marcus Meissner <meissner@suse.com>
- switch source url to https
* Mon Dec 28 2020 pgajdos@suse.com
- version update to 2020.12.07
  * Various new words.
  * Variant cleanups.
  * Bump irregardless, froward (+ derivatives) and perpend to level 70.
* Mon Oct 12 2020 pgajdos@suse.com
- removing Novell residues
- deleted patches
  - aspell-en-Novellwords_extra_dict.patch (not needed)
- deleted sources
  - Nwordlist.tgz (abandoned)
* Mon Oct 12 2020 pgajdos@suse.com
- do not require aspell binary, dictionary can be used
  by the aspell library [bsc#1177523]
* Thu Dec 19 2019 pgajdos@suse.com
- version update to 2019.10.06
  Various new words.
  Remove compare's and fail's.
* Sat Aug 11 2018 amajer@suse.com
- run fdupes only on dictionary data
- update keyring to include all upstream signatures
- update URL
* Sat Aug 11 2018 rpm@fthiessen.de
- Use SourceURL
- Use GPG signed source
- updated to 2018.04.16
  * various new words (see SCOWL-README for other changes)
* Mon Dec 18 2017 pgajdos@suse.com
- updated to 2017.08.24
  * various new words (see SCOWL-README for other changes)
* Mon Nov 21 2016 pgajdos@suse.com
- updated to 2016.11.20:
  * various new words (see SCOWL-README for other changes)
* Mon May 11 2015 pgajdos@suse.com
- updated to 2015.03.24:
  * Updated to SCOWL 2015.02.15 which added a large number of new words
    such as "inbox", "smartphone", and "selfie" and removed some
    problematic words.
* Wed Feb 29 2012 cfarrell@suse.com
- license update: MIT and BSD-3-Clause
  Use SPDX format (using same license form as Fedora for this package)
* Sat Jan 28 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Sun Apr 10 2011 asterios.dramis@gmail.com
- Updated to version 7.1-0:
  * Updated to SCOWL 7.1 which corrected several errors and also added
    several now common proper names and some other words now in
    common use.
  From 7.0:
  * Updated to SCOWL 7 which was created with a new version of Varcon
    which corrected many errors, especially in the British and Canadian
    dictionaries. Numerous other corrections are also included.
  * Added en_CA-variant_* and en_GB-variant_* auxiliary dictionaries.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Added description for the patch based on openSUSE Patches Guidelines.
  * Updates in %%description.
  * Run %%fdupes to fix rpmlint warning "files-duplicate".
  * Minor other updates.
- Rebased Novellwords_extra_dict.patch to apply cleanly.
* Mon Jul 12 2010 pgajdos@suse.cz
- fixed url [bnc#620786]
* Mon Jan 19 2009 pgajdos@suse.cz
- Novell words for en_{CA,GB,US} [bnc#462871]
  + updated Novellwords_extra_dict.patch
* Mon Sep  3 2007 lmichnovic@suse.cz
- updated Nwordlist (words: Firefox,Thunderbird, NLD, ...) [#371]
* Fri Jul 27 2007 lmichnovic@suse.cz
- added "Bugzilla" to Novell words
* Tue Jun  5 2007 lmichnovic@suse.cz
- creating extra dictionary with Novell words during building[#371]
* Wed May  2 2007 lmichnovic@suse.cz
- added extra dictionary with Novell words [#371]
* Mon Oct 23 2006 lmichnovic@suse.cz
- fixed version of aspell in Requires
* Mon Mar 20 2006 pnemec@suse.cz
- removed aspell_dictionary from Provides
* Fri Mar  3 2006 ro@suse.de
- fixed lang provides format
* Fri Mar  3 2006 pnemec@suse.cz
- converted to the new lang provides format
* Tue Feb  7 2006 pnemec@suse.cz
- fixed virtual package name
* Fri Jan 27 2006 pnemec@suse.cz
- providing aspell_dictionary as virtual package [#144972]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Mar 18 2005 gekker@suse.de
- Update to version 6.0 (72354, 72377).
* Fri Dec  3 2004 ro@suse.de
- added some magic for the filelist
* Wed Apr 21 2004 ltinkl@suse.cz
- updated to version 0.51-1
* Fri Jan 31 2003 pmladek@suse.cz
- updated to version 0.51-0:
  * added variants that were not really spelling variants
  * removed some spelling variants and other strange words
  * removed rarely used inflections of a word
  * removed the DEC Word List due to the questionable license
- installed ChangeLog and SCOWL-README as the documentation too
* Fri Nov  1 2002 pmladek@suse.cz
- package created, version 0.50.2
